@@ -40,14 +40,14 @@ class OctaviaException(Exception):
                 self.message = args[0]
                 self.orig_msg = kwargs.get('orig_msg')
                 self.orig_code = kwargs.get('orig_code')
-            super(OctaviaException, self).__init__(self.message % kwargs)
+            super().__init__(self.message % kwargs)
             self.msg = self.message % kwargs
         except Exception:
             with excutils.save_and_reraise_exception() as ctxt:
                 if not self.use_fatal_exceptions():
                     ctxt.reraise = False
                     # at least get the core message out if something happened
-                    super(OctaviaException, self).__init__(self.message)
+                    super().__init__(self.message)
 
     def __unicode__(self):
         return self.msg
@@ -66,7 +66,7 @@ class APIException(exc.HTTPClientError):
 
     def __init__(self, **kwargs):
         self.msg = self.msg % kwargs
-        super(APIException, self).__init__(detail=self.msg)
+        super().__init__(detail=self.msg)
 
 
 class NotFound(APIException):
@@ -232,8 +232,8 @@ class NoReadyAmphoraeException(OctaviaException):
     message = _('There are not any READY amphora available.')
 
 
-class GlanceNoTaggedImages(OctaviaException):
-    message = _("No Glance images are tagged with %(tag)s tag.")
+class ImageGetException(OctaviaException):
+    message = _('Failed to retrieve image with %(tag)s tag.')
 
 
 # This is an internal use exception for the taskflow work flow
@@ -414,3 +414,8 @@ class NetworkServiceError(OctaviaException):
 class InvalidIPAddress(APIException):
     msg = _('The IP Address %(ip_addr)s is invalid.')
     code = 400
+
+
+class AmphoraNetworkConfigException(OctaviaException):
+    message = _('Cannot configure network resource in the amphora: '
+                '%(detail)s')
