@@ -44,8 +44,8 @@ def url(url, require_scheme=True):
         if require_scheme:
             if p_url.scheme != 'http' and p_url.scheme != 'https':
                 raise exceptions.InvalidURL(url=url)
-    except Exception:
-        raise exceptions.InvalidURL(url=url)
+    except Exception as e:
+        raise exceptions.InvalidURL(url=url) from e
     return True
 
 
@@ -63,8 +63,8 @@ def url_path(url_path):
 
         if invalid_path:
             raise exceptions.InvalidURLPath(url_path=url_path)
-    except Exception:
-        raise exceptions.InvalidURLPath(url_path=url_path)
+    except Exception as e:
+        raise exceptions.InvalidURLPath(url_path=url_path) from e
     return True
 
 
@@ -317,8 +317,8 @@ def port_exists(port_id, context=None):
     network_driver = utils.get_network_driver()
     try:
         port = network_driver.get_port(port_id, context=context)
-    except Exception:
-        raise exceptions.InvalidSubresource(resource='Port', id=port_id)
+    except Exception as e:
+        raise exceptions.InvalidSubresource(resource='Port', id=port_id) from e
     return port
 
 
@@ -336,8 +336,9 @@ def subnet_exists(subnet_id, context=None):
     network_driver = utils.get_network_driver()
     try:
         subnet = network_driver.get_subnet(subnet_id, context=context)
-    except Exception:
-        raise exceptions.InvalidSubresource(resource='Subnet', id=subnet_id)
+    except Exception as e:
+        raise exceptions.InvalidSubresource(
+            resource='Subnet', id=subnet_id) from e
     return subnet
 
 
@@ -346,9 +347,9 @@ def qos_policy_exists(qos_policy_id):
     qos_extension_enabled(network_driver)
     try:
         qos_policy = network_driver.get_qos_policy(qos_policy_id)
-    except Exception:
-        raise exceptions.InvalidSubresource(resource='qos_policy',
-                                            id=qos_policy_id)
+    except Exception as e:
+        raise exceptions.InvalidSubresource(
+            resource='qos_policy', id=qos_policy_id) from e
     return qos_policy
 
 
@@ -367,8 +368,9 @@ def network_exists_optionally_contains_subnet(network_id, subnet_id=None,
     network_driver = utils.get_network_driver()
     try:
         network = network_driver.get_network(network_id, context=context)
-    except Exception:
-        raise exceptions.InvalidSubresource(resource='Network', id=network_id)
+    except Exception as e:
+        raise exceptions.InvalidSubresource(
+            resource='Network', id=network_id) from e
     if subnet_id:
         if not network.subnets or subnet_id not in network.subnets:
             raise exceptions.InvalidSubresource(resource='Subnet',
@@ -414,9 +416,9 @@ def check_session_persistence(SP_dict):
                 '"APP_COOKIE" session persistence type.'))
     except exceptions.ValidationException:
         raise
-    except Exception:
+    except Exception as e:
         raise exceptions.ValidationException(detail=_(
-            'Invalid session_persistence provided.'))
+            'Invalid session_persistence provided.')) from e
 
 
 def ip_not_reserved(ip_address):
@@ -427,9 +429,99 @@ def ip_not_reserved(ip_address):
                                        option='member address')
 
 
-def is_flavor_spares_compatible(flavor):
-    if flavor:
-        # If a compute flavor is specified, the flavor is not spares compatible
-        if flavor.get(constants.COMPUTE_FLAVOR, None):
-            return False
-    return True
+def check_cipher_prohibit_list(cipherstring):
+    ciphers = cipherstring.split(':')
+    prohibit_list = CONF.api_settings.tls_cipher_prohibit_list.split(':')
+    rejected = []
+    for cipher in ciphers:
+        if cipher in prohibit_list:
+            rejected.append(cipher)
+    return rejected
+
+
+def check_default_ciphers_prohibit_list_conflict():
+    listener_rejected = check_cipher_prohibit_list(
+        CONF.api_settings.default_listener_ciphers)
+    if listener_rejected:
+        raise exceptions.ValidationException(
+            detail=_('Default listener ciphers conflict with prohibit list. '
+                     'Conflicting ciphers: ' + ', '.join(listener_rejected)))
+
+    pool_rejected = check_cipher_prohibit_list(
+        CONF.api_settings.default_pool_ciphers)
+    if pool_rejected:
+        raise exceptions.ValidationException(
+            detail=_('Default pool ciphers conflict with prohibit list. '
+                     'Conflicting ciphers: ' + ', '.join(pool_rejected)))
+
+
+def check_tls_version_list(versions):
+    if versions == []:
+        raise exceptions.ValidationException(
+            detail=_('Empty TLS version list. Either specify at least one TLS '
+                     'version or remove this parameter to use the default.'))
+
+    # Unset action
+    if versions is None:
+        return
+
+    invalid_versions = [v for v in versions
+                        if v not in constants.TLS_ALL_VERSIONS]
+    if invalid_versions:
+        raise exceptions.ValidationException(
+            detail=_('Invalid TLS versions: ' + ', '.join(invalid_versions)))
+
+
+def check_tls_version_min(versions, message=None):
+    """Checks a TLS version string against the configured minimum."""
+
+    if not CONF.api_settings.minimum_tls_version:
+        return
+
+    if not message:
+        message = _("Requested TLS versions are less than the minimum: ")
+
+    min_ver_index = constants.TLS_ALL_VERSIONS.index(
+        CONF.api_settings.minimum_tls_version)
+
+    rejected = []
+    for ver in versions:
+        if constants.TLS_ALL_VERSIONS.index(ver) < min_ver_index:
+            rejected.append(ver)
+    if rejected:
+        raise exceptions.ValidationException(detail=(
+            message + ', '.join(rejected) + " < " +
+            CONF.api_settings.minimum_tls_version))
+
+
+def check_default_tls_versions_min_conflict():
+    if not CONF.api_settings.minimum_tls_version:
+        return
+
+    listener_message = _("Default listener TLS versions are less than the "
+                         "minimum: ")
+    pool_message = _("Default pool TLS versions are less than the minimum: ")
+
+    check_tls_version_min(CONF.api_settings.default_listener_tls_versions,
+                          message=listener_message)
+
+    check_tls_version_min(CONF.api_settings.default_pool_tls_versions,
+                          message=pool_message)
+
+
+def check_alpn_protocols(protocols):
+    if protocols == []:
+        raise exceptions.ValidationException(
+            detail=_('Empty ALPN protocol list. Either specify at least one '
+                     'ALPN protocol or remove this parameter to use the '
+                     'default.'))
+
+    # Unset action
+    if protocols is None:
+        return
+
+    invalid_protocols = [p for p in protocols
+                         if p not in constants.SUPPORTED_ALPN_PROTOCOLS]
+    if invalid_protocols:
+        raise exceptions.ValidationException(
+            detail=_('Invalid ALPN protocol: ' + ', '.join(invalid_protocols)))
