@@ -107,29 +107,6 @@ class ControllerWorker(object):
             with tf_logging.DynamicLoggingListener(tf, log=LOG):
                 tf.run()
 
-    def create_amphora(self, availability_zone=None):
-        """Creates an Amphora.
-
-        This is used to create spare amphora.
-
-        :returns: uuid
-        """
-        try:
-            store = {constants.BUILD_TYPE_PRIORITY:
-                     constants.LB_CREATE_SPARES_POOL_PRIORITY,
-                     constants.FLAVOR: None,
-                     constants.SERVER_GROUP_ID: None,
-                     constants.AVAILABILITY_ZONE: None}
-            if availability_zone:
-                store[constants.AVAILABILITY_ZONE] = (
-                    self._az_repo.get_availability_zone_metadata_dict(
-                        db_apis.get_session(), availability_zone))
-            self.run_flow(
-                flow_utils.get_create_amphora_flow,
-                store=store, wait=True)
-        except Exception as e:
-            LOG.error('Failed to create an amphora due to: %s', str(e))
-
     def delete_amphora(self, amphora_id):
         """Deletes an existing Amphora.
 
@@ -449,8 +426,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoSuitablePool: Unable to find the node pool
         """
-        pool = self._pool_repo.get(db_apis.get_session(),
-                                   id=member[constants.POOL_ID])
+        db_member = self._member_repo.get(db_apis.get_session(),
+                                          id=member[constants.MEMBER_ID])
+        if not db_member:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7member',
+                        member[constants.MEMBER_ID])
+            raise db_exceptions.NoResultFound
+
+        pool = db_member.pool
         load_balancer = pool.load_balancer
         provider_lb = provider_utils.db_loadbalancer_to_provider_loadbalancer(
             load_balancer).to_dict()
@@ -716,8 +700,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_listener = self._listener_repo.get(
-            db_apis.get_session(), id=l7policy[constants.LISTENER_ID])
+        db_l7policy = self._l7policy_repo.get(
+            db_apis.get_session(), id=l7policy[constants.L7POLICY_ID])
+        if not db_l7policy:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7policy',
+                        l7policy[constants.L7POLICY_ID])
+            raise db_exceptions.NoResultFound
+
+        db_listener = db_l7policy.listener
 
         listeners_dicts = (
             provider_utils.db_listeners_to_provider_dicts_list_of_dicts(
@@ -790,8 +781,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_l7policy = self._l7policy_repo.get(db_apis.get_session(),
-                                              id=l7rule[constants.L7POLICY_ID])
+        db_l7rule = self._l7rule_repo.get(db_apis.get_session(),
+                                          id=l7rule[constants.L7RULE_ID])
+        if not db_l7rule:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7rule',
+                        l7rule[constants.L7RULE_ID])
+            raise db_exceptions.NoResultFound
+
+        db_l7policy = db_l7rule.l7policy
 
         load_balancer = db_l7policy.listener.load_balancer
 
@@ -945,8 +943,7 @@ class ControllerWorker(object):
                              constants.LOADBALANCER: provider_lb_dict,
                              constants.SERVER_GROUP_ID: server_group_id,
                              constants.LOADBALANCER_ID: lb_id,
-                             constants.VIP: vip_dict,
-                             constants.AMPHORA_ID: amphora_id}
+                             constants.VIP: vip_dict}
 
             self.run_flow(
                 flow_utils.get_failover_amphora_flow,
