@@ -16,7 +16,6 @@
 
 from oslo_config import cfg
 from oslo_log import log as logging
-from taskflow.patterns import graph_flow
 from taskflow.patterns import linear_flow
 from taskflow.patterns import unordered_flow
 
@@ -82,33 +81,7 @@ class AmphoraFlows(object):
 
         return create_amphora_flow
 
-    def _get_post_map_lb_subflow(self, prefix, role):
-        """Set amphora type after mapped to lb."""
-
-        sf_name = prefix + '-' + constants.POST_MAP_AMP_TO_LB_SUBFLOW
-        post_map_amp_to_lb = linear_flow.Flow(
-            sf_name)
-
-        post_map_amp_to_lb.add(amphora_driver_tasks.AmphoraConfigUpdate(
-            name=sf_name + '-' + constants.AMPHORA_CONFIG_UPDATE_TASK,
-            requires=(constants.AMPHORA, constants.FLAVOR)))
-
-        if role == constants.ROLE_MASTER:
-            post_map_amp_to_lb.add(database_tasks.MarkAmphoraMasterInDB(
-                name=sf_name + '-' + constants.MARK_AMP_MASTER_INDB,
-                requires=constants.AMPHORA))
-        elif role == constants.ROLE_BACKUP:
-            post_map_amp_to_lb.add(database_tasks.MarkAmphoraBackupInDB(
-                name=sf_name + '-' + constants.MARK_AMP_BACKUP_INDB,
-                requires=constants.AMPHORA))
-        elif role == constants.ROLE_STANDALONE:
-            post_map_amp_to_lb.add(database_tasks.MarkAmphoraStandAloneInDB(
-                name=sf_name + '-' + constants.MARK_AMP_STANDALONE_INDB,
-                requires=constants.AMPHORA))
-
-        return post_map_amp_to_lb
-
-    def _get_create_amp_for_lb_subflow(self, prefix, role, is_spare=False):
+    def get_amphora_for_lb_subflow(self, prefix, role):
         """Create a new amphora for lb."""
 
         sf_name = prefix + '-' + constants.CREATE_AMP_FOR_LB_SUBFLOW
@@ -153,16 +126,10 @@ class AmphoraFlows(object):
         create_amp_for_lb_subflow.add(amphora_driver_tasks.AmphoraFinalize(
             name=sf_name + '-' + constants.AMPHORA_FINALIZE,
             requires=constants.AMPHORA))
-        if is_spare:
-            create_amp_for_lb_subflow.add(
-                database_tasks.MarkAmphoraReadyInDB(
-                    name=sf_name + '-' + constants.MARK_AMPHORA_READY_INDB,
-                    requires=constants.AMPHORA))
-        else:
-            create_amp_for_lb_subflow.add(
-                database_tasks.MarkAmphoraAllocatedInDB(
-                    name=sf_name + '-' + constants.MARK_AMPHORA_ALLOCATED_INDB,
-                    requires=(constants.AMPHORA, constants.LOADBALANCER_ID)))
+        create_amp_for_lb_subflow.add(
+            database_tasks.MarkAmphoraAllocatedInDB(
+                name=sf_name + '-' + constants.MARK_AMPHORA_ALLOCATED_INDB,
+                requires=(constants.AMPHORA, constants.LOADBALANCER_ID)))
         if role == constants.ROLE_MASTER:
             create_amp_for_lb_subflow.add(database_tasks.MarkAmphoraMasterInDB(
                 name=sf_name + '-' + constants.MARK_AMP_MASTER_INDB,
@@ -179,22 +146,6 @@ class AmphoraFlows(object):
 
         return create_amp_for_lb_subflow
 
-    def _allocate_amp_to_lb_decider(self, history):
-        """decides if the lb shall be mapped to a spare amphora
-
-        :return: True if a spare amphora exists in DB
-        """
-
-        return list(history.values())[0] is not None
-
-    def _create_new_amp_for_lb_decider(self, history):
-        """decides if a new amphora must be created for the lb
-
-        :return: True if there is no spare amphora
-        """
-        values = history.values()
-        return not values or list(values)[0] is None
-
     def _retry_flow(self, sf_name):
         retry_task = sf_name + '-' + constants.AMP_COMPUTE_CONNECTIVITY_WAIT
         retry_subflow = linear_flow.Flow(
@@ -206,97 +157,6 @@ class AmphoraFlows(object):
                 inject={'raise_retry_exception': True}))
         return retry_subflow
 
-    def _finalize_flow(self, sf_name, role):
-        sf_name = sf_name + constants.FINALIZE_AMPHORA_FLOW
-        create_amp_for_lb_subflow = linear_flow.Flow(sf_name)
-        create_amp_for_lb_subflow.add(amphora_driver_tasks.AmphoraFinalize(
-            name=sf_name + '-' + constants.AMPHORA_FINALIZE,
-            requires=constants.AMPHORA))
-        create_amp_for_lb_subflow.add(
-            database_tasks.MarkAmphoraAllocatedInDB(
-                name=sf_name + '-' + constants.MARK_AMPHORA_ALLOCATED_INDB,
-                requires=(constants.AMPHORA, constants.LOADBALANCER_ID)))
-        create_amp_for_lb_subflow.add(database_tasks.ReloadAmphora(
-            name=sf_name + '-' + constants.RELOAD_AMPHORA,
-            requires=constants.AMPHORA,
-            provides=constants.AMPHORA))
-
-        if role == constants.ROLE_MASTER:
-            create_amp_for_lb_subflow.add(database_tasks.MarkAmphoraMasterInDB(
-                name=sf_name + '-' + constants.MARK_AMP_MASTER_INDB,
-                requires=constants.AMPHORA))
-        elif role == constants.ROLE_BACKUP:
-            create_amp_for_lb_subflow.add(database_tasks.MarkAmphoraBackupInDB(
-                name=sf_name + '-' + constants.MARK_AMP_BACKUP_INDB,
-                requires=constants.AMPHORA))
-        elif role == constants.ROLE_STANDALONE:
-            create_amp_for_lb_subflow.add(
-                database_tasks.MarkAmphoraStandAloneInDB(
-                    name=sf_name + '-' + constants.MARK_AMP_STANDALONE_INDB,
-                    requires=constants.AMPHORA))
-        return create_amp_for_lb_subflow
-
-    def get_amphora_for_lb_subflow(
-            self, prefix, role=constants.ROLE_STANDALONE, is_spare=False):
-        """Tries to allocate a spare amphora to a loadbalancer if none
-
-        exists, create a new amphora.
-        """
-
-        sf_name = prefix + '-' + constants.GET_AMPHORA_FOR_LB_SUBFLOW
-
-        # Don't replace a spare with another spare, just build a fresh one.
-        if is_spare:
-            get_spare_amp_flow = linear_flow.Flow(sf_name)
-
-            get_spare_amp_flow.add(self._get_create_amp_for_lb_subflow(
-                prefix, role, is_spare=is_spare))
-            return get_spare_amp_flow
-
-        # We need a graph flow here for a conditional flow
-        amp_for_lb_flow = graph_flow.Flow(sf_name)
-
-        # Setup the task that maps an amphora to a load balancer
-        allocate_and_associate_amp = database_tasks.MapLoadbalancerToAmphora(
-            name=sf_name + '-' + constants.MAP_LOADBALANCER_TO_AMPHORA,
-            requires=(constants.LOADBALANCER_ID, constants.FLAVOR,
-                      constants.AVAILABILITY_ZONE),
-            provides=constants.AMPHORA)
-
-        # Define a subflow for if we successfully map an amphora
-        map_lb_to_amp = self._get_post_map_lb_subflow(prefix, role)
-        # Define a subflow for if we can't map an amphora
-        create_amp = self._get_create_amp_for_lb_subflow(prefix, role)
-        # TODO(ataraday): Have to split create flow due lack of functionality
-        # in taskflow: related https://bugs.launchpad.net/taskflow/+bug/1480907
-        retry_flow = self._retry_flow(sf_name)
-        finalize_flow = self._finalize_flow(sf_name, role)
-
-        # Add them to the graph flow
-        amp_for_lb_flow.add(allocate_and_associate_amp,
-                            map_lb_to_amp, create_amp,
-                            retry_flow, finalize_flow, resolve_requires=False)
-
-        # Setup the decider for the path if we can map an amphora
-        amp_for_lb_flow.link(allocate_and_associate_amp, map_lb_to_amp,
-                             decider=self._allocate_amp_to_lb_decider,
-                             decider_depth='flow')
-        # Setup the decider for the path if we can't map an amphora
-        amp_for_lb_flow.link(allocate_and_associate_amp, create_amp,
-                             decider=self._create_new_amp_for_lb_decider,
-                             decider_depth='flow')
-        # TODO(ataraday): setup separate deciders as we need retry flow
-        #  properly ignored
-        amp_for_lb_flow.link(create_amp, retry_flow,
-                             decider=self._create_new_amp_for_lb_decider,
-                             decider_depth='flow')
-
-        amp_for_lb_flow.link(retry_flow, finalize_flow,
-                             decider=self._create_new_amp_for_lb_decider,
-                             decider_depth='flow')
-
-        return amp_for_lb_flow
-
     def get_delete_amphora_flow(
             self, amphora,
             retry_attempts=CONF.controller_worker.amphora_delete_retries,
@@ -480,7 +340,7 @@ class AmphoraFlows(object):
 
     def get_amphora_for_lb_failover_subflow(
             self, prefix, role=constants.ROLE_STANDALONE,
-            failed_amp_vrrp_port_id=None, is_vrrp_ipv6=False, is_spare=False):
+            failed_amp_vrrp_port_id=None, is_vrrp_ipv6=False):
         """Creates a new amphora that will be used in a failover flow.
 
         :requires: loadbalancer_id, flavor, vip, vip_sg_id, loadbalancer
@@ -489,7 +349,6 @@ class AmphoraFlows(object):
         :param role: The role this amphora will have in the topology.
         :param failed_amp_vrrp_port_id: The base port ID of the failed amp.
         :param is_vrrp_ipv6: True if the base port IP is IPv6.
-        :param is_spare: True if we are getting a spare amphroa.
         :return: A Taskflow sub-flow that will create the amphora.
         """
 
@@ -500,11 +359,7 @@ class AmphoraFlows(object):
         # Try to allocate or boot an amphora instance (unconfigured)
         amp_for_failover_flow.add(self.get_amphora_for_lb_subflow(
             prefix=prefix + '-' + constants.FAILOVER_LOADBALANCER_FLOW,
-            role=role, is_spare=is_spare))
-
-        # If we are getting a spare amphora, this is all we need to do.
-        if is_spare:
-            return amp_for_failover_flow
+            role=role))
 
         # Create the VIP base (aka VRRP) port for the amphora.
         amp_for_failover_flow.add(network_tasks.CreateVIPBasePort(
@@ -592,8 +447,6 @@ class AmphoraFlows(object):
             amp_role = 'master_or_backup'
         elif failed_amphora[constants.ROLE] == constants.ROLE_STANDALONE:
             amp_role = 'standalone'
-        elif failed_amphora[constants.ROLE] is None:
-            amp_role = 'spare'
         else:
             amp_role = 'undefined'
         LOG.info("Performing failover for amphora: %s",
@@ -616,10 +469,8 @@ class AmphoraFlows(object):
             requires=constants.LOADBALANCER_ID,
             provides=constants.VIP_SG_ID))
 
-        is_spare = True
         is_vrrp_ipv6 = False
         if failed_amphora.get(constants.LOAD_BALANCER_ID):
-            is_spare = False
             if failed_amphora.get(constants.VRRP_IP):
                 is_vrrp_ipv6 = utils.is_ipv6(failed_amphora[constants.VRRP_IP])
 
@@ -637,8 +488,7 @@ class AmphoraFlows(object):
                 role=failed_amphora[constants.ROLE],
                 failed_amp_vrrp_port_id=failed_amphora.get(
                     constants.VRRP_PORT_ID),
-                is_vrrp_ipv6=is_vrrp_ipv6,
-                is_spare=is_spare))
+                is_vrrp_ipv6=is_vrrp_ipv6))
 
         failover_amp_flow.add(
             self.get_delete_amphora_flow(
@@ -652,7 +502,7 @@ class AmphoraFlows(object):
                 inject={constants.AMPHORA: failed_amphora}))
 
         if not failed_amphora.get(constants.LOAD_BALANCER_ID):
-            # This is an unallocated amphora (spares pool), we are done.
+            # This is an unallocated amphora (bogus), we are done.
             return failover_amp_flow
 
         failover_amp_flow.add(database_tasks.GetLoadBalancer(
